//
//  RTV.h
//  RTV
//
//  Created by Michael Rothwell on Sun Jan 18 2004.
//  Copyright (c) 2004 Michael Rothwell. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "RTVShow.h"
#import "ImageFromMPEGStream.h"

#include <fcntl.h>

@interface RTV : NSObject
{
    // big flag
    BOOL active;

    // info about this RTV
    NSMutableDictionary *m_info;

    // cache of ls queries
    NSMutableDictionary *m_cache_ls;
    
    // for thread safety
    NSRecursiveLock *m_lock;

    // array of shows
    NSMutableArray *m_Shows;

    // array of pending downloads
    NSMutableArray *m_Queue;

    // index of shows
    NSMutableDictionary *m_ShowsIndex;

    // timer
    NSTimer *m_RefreshTimer;

    // cache dir
    NSString *m_cacheDir;
    
    //flag for getting the time offset
    BOOL have_Offset;
    
    // currently selected show
    RTVShow * m_selectedShow;
    
    int active_downloads;
    int max_downloads;
    
    int dl_sleep;
    

}
+(id)RTVWithURL:(NSURL *)url;
+(id)RTVWithIPAddress:(NSString *)IPAddress;

-(void)refreshDeviceInfo;
-(void)findTimeOffset;
-(void)updateGuide;
-(NSNumber *)timeOffset;

-(id)init;
-(id)initWithIPAddress:(NSString *)IPAddress;

-(NSString *)cacheDir;

-(NSString *)IPAddress;
-(void)IPAddress:(NSString *)IPAddress;

-(NSString *)serialNumber;
-(void)serialNumber:(NSString *)serialNumber;

-(NSString *)name;
-(void)name:(NSString *)name;
-(NSString *)friendlyName;
-(NSString *)modelNumber;

-(NSString *)xmlGuide;

-(RTVShow *)showWithShowID:(NSString *)showID;

-(void)sortBy:(NSString *)sortField;

-(void)shutDown;

-(NSArray *)shows;
-(int)showCount;

-(BOOL)isAlive;

-(int)secondsSinceGuideUpdate;

-(void)saveGuideData:(NSString *)filename;

- (NSArray *)pathWithPath:(NSString *)path;

-(int)maxGuideAge;
-(void)maxGuideAge:(int)seconds;

-(int)throttle;
-(void)throttle:(int)val;

-(int)maxDownloads;
-(void)maxDownloads:(int)max;

-(void)removeFromPrefs;
-(void)saveToPrefs;

-(void)abortDownload:(NSString *)source;

- (void)downloadFile:(NSString *)source withObject:(id)obj;

- (void)downloadFileToFile:(NSString *)source dest:(NSString *)dest withObject:(id)obj;
- (void)downloadFileOverFile:(NSString *)source dest:(NSString *)dest withObject:(id)obj;

- (void)uploadFileToFile:(NSString *)source dest:(NSString *)dest withObject:(id)obj;

-(void)clearDirCache;

- (void)createDirectory:(NSString *)path withObject:(id)obj;

-(void)select:(RTVShow *)rtvshow;
-(RTVShow *)selected;

// "private"
-(NSMutableData *)sync_RTVRequest:(NSString *)IPAddress req:(char *)req;
-(void)activityStart:(id)obj;
-(void)activityEnd:(id)obj;
@end
